package org.jmetrix.bus.impl;

import org.jmetrix.bus.Bus;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * @author Konstantin Kuzmin
 * @version $Revision$
 * @since 01.10.11
 */
public class NamedBusFactory {
    private static final Map<String, Bus> nameToBus = new ConcurrentHashMap<String, Bus>();
    public static final String DEFAULT_BUS = "JMETRIX_DEFAULT_BUS";

    private NamedBusFactory() {
    }

    public static Bus getBus(final String name) {
        Bus bus = nameToBus.get(name);
        if (bus == null) {
            synchronized (nameToBus) {
                if (null == nameToBus.get(name)) {
                    bus = new NamedBus(name);
                    nameToBus.put(name, bus);
                }
            }
        }
        return bus;
    }

    public static Bus getDefaultBus() {
        return getBus(DEFAULT_BUS);
    }

    static synchronized void removeBus(final String name) {
        nameToBus.remove(name);
    }

}
